@@ -47,6 +47,8 @@ Diagram::Diagram()
    valueGoodFrameColor(0.64,0.64,0.64,Lum::OS::display->blackColor),
    valueBadColor(1.0,0.82,0.82,Lum::OS::display->blackColor),
    valueBadFrameColor(0.8,0.58,0.58,Lum::OS::display->blackColor),
+   font(Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
+                                  Lum::OS::Display::fontScaleFootnote)),
    mode(modeFullDay)
 {
   SetBackground(Lum::OS::display->GetFill(Lum::OS::Display::graphBackgroundFillIndex));
@@ -65,29 +67,12 @@ Diagram::Diagram()
   AttachModel(date);
 }
 
-Diagram::~Diagram()
-{
-  UnattachModel(date);
-
-  UnattachModel(minValue);
-  UnattachModel(maxValue);
-  UnattachModel(bottomValue);
-  UnattachModel(topValue);
-
-  UnattachModel(minWeight);
-  UnattachModel(maxWeight);
-  UnattachModel(bottomWeight);
-  UnattachModel(topWeight);
-}
-
 void Diagram::CalcSize()
 {
-  Lum::OS::FontRef font;
-  size_t           digitWidth=0;
+  size_t digitWidth=0;
 
   fullDayWidth=0;
   smallDayWidth=0;
-  font=Lum::OS::display->GetFont();
 
   for (size_t i=0; i<10; i++) {
     digitWidth=std::max(digitWidth,font->StringWidth(Lum::Base::NumberToWString(i)));
@@ -324,7 +309,6 @@ void Diagram::PrintHorizontalScale(Lum::OS::DrawInfo* draw,
                                    size_t dayWidth,
                                    const Lum::Base::Calendar& start)
 {
-  Lum::OS::FontRef    font=Lum::OS::display->GetFont();
   std::wstring        tmp;
   Lum::Base::Calendar day;
 
@@ -383,8 +367,6 @@ void Diagram::PrintHorizontalScale(Lum::OS::DrawInfo* draw,
  */
 void Diagram::PrintVerticalScale(Lum::OS::DrawInfo* draw)
 {
-  Lum::OS::FontRef font=Lum::OS::display->GetFont();
-
   draw->PushForeground(Lum::OS::Display::graphScaleColor);
   draw->PushFont(font);
 
@@ -549,7 +531,7 @@ bool Diagram::HandleMouseEvent(const Lum::OS::MouseEvent& event)
       day.AddDays((event.x-x+hAdjustment->GetTop()-1)/GetDayWidth());
 
       date->Set(day);
-      currentTab->Set(0);
+      currentTab->Set(1);
     }
     return true;
   }
