@@ -27,10 +27,10 @@
 #include <Lum/Space.h>
 #include <Lum/Tab.h>
 #include <Lum/View.h>
-#include <Lum/WindowGroup.h>
 
 #include <Lum/Dlg/About.h>
 #include <Lum/Dlg/File.h>
+#include <Lum/Dlg/Help.h>
 #include <Lum/Dlg/Msg.h>
 
 #include <Lum/Model/Action.h>
@@ -42,11 +42,11 @@
 #include "Configuration.h"
 #include "Diagram.h"
 #include "DataInput.h"
-#include "Help.h"
+#include "FoodInput.h"
 #include "ImportExport.h"
 #include "Preferences.h"
 #include "Statistics.h"
-#include <iostream>
+
 static Lum::AppInfo info;
 
 class MainDialog : public Lum::Dialog
@@ -61,6 +61,7 @@ private:
   Lum::Model::ActionRef helpAction;
   Lum::Model::ActionRef aboutAction;
 
+  FoodInput             *foodInput;
   DataInput             *dataInput;
   Diagram               *diagram;
 
@@ -88,32 +89,11 @@ public:
     AttachModel(aboutAction);
   }
 
-  ~MainDialog()
-  {
-    UnattachModel(aboutAction);
-    UnattachModel(helpAction);
-    UnattachModel(configAction);
-    UnattachModel(statisticsAction);
-    UnattachModel(restoreAction);
-    UnattachModel(backupAction);
-    UnattachModel(exportAction);
-    UnattachModel(importAction);
-
-    UnattachModel(GetClosedAction());
-    UnattachModel(GetOpenedAction());
-  }
-
   void PreInit()
   {
-    Lum::Menu        *menu;
-    Lum::MenuStrip   *menuStrip;
-    Lum::Panel       *panel;
-    Lum::Tab         *tab;
-    Lum::View        *view;
-    Lum::WindowGroup *wGroup;
-
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
+    Lum::Panel *panel;
+    Lum::Tab   *tab;
+    Lum::View  *view;
 
     panel=new Lum::VPanel();
     panel->SetFlex(true,true);
@@ -122,10 +102,15 @@ public:
     tab->SetFlex(true,true);
     tab->SetModel(currentTab);
 
+    foodInput=new FoodInput();
+    foodInput->SetFlex(true,true);
+
+    tab->Add(_(L"MAIN_TAB_FOODINPUT",L"Food"),foodInput);
+
     dataInput=new DataInput();
     dataInput->SetFlex(true,true);
 
-    tab->Add(_(L"MAIN_TAB_INPUT",L"Input"),dataInput);
+    tab->Add(_(L"MAIN_TAB_INPUT",L"Day view"),dataInput);
 
     view=new Lum::View();
     view->SetFlex(true,true);
@@ -138,34 +123,30 @@ public:
 
     panel->Add(tab);
 
-    wGroup->SetMain(panel);
+    SetMain(panel);
 
-    menuStrip=new Lum::MenuStrip();
+    Lum::MenuDesc *menu=new Lum::MenuDesc();
 
-    menu=new Lum::Menu();
-    menu->AddActionItem(_(L"MENU_IMPORT_FOOD_COMPONENTS",L"_Import food components..."),importAction,Lum::OS::qualifierControl,L"i");
-    menu->AddActionItem(_(L"MENU_EXPORT_FOOD_COMPONENTS",L"_Export food components..."),exportAction,Lum::OS::qualifierControl,L"e");
-    menu->AddSeparator();
-    menu->AddActionItem(_(L"MENU_BACKUP",L"_Backup..."),backupAction);
-    menu->AddActionItem(_(L"MENU_RESTORE",L"_Restore..."),restoreAction);
-    menu->AddSeparator();
-    menu->AddActionItem(_ld(menuProjectQuit),GetClosedAction(),Lum::OS::qualifierControl,L"q");
-    menuStrip->AddPullDownMenu(_ld(menuProject),menu);
+    menu
+      ->AddMenuItemSub(_ld(menuProject))
+        ->AddMenuItemAction(_(L"MENU_IMPORT_FOOD_COMPONENTS",L"_Import food components..."),Lum::OS::qualifierControl,L"i",importAction)
+        ->AddMenuItemAction(_(L"MENU_EXPORT_FOOD_COMPONENTS",L"_Export food components..."),Lum::OS::qualifierControl,L"e",exportAction)
+        ->AddSeparator()
+        ->AddMenuItemAction(_(L"MENU_BACKUP",L"_Backup..."),backupAction)
+        ->AddMenuItemAction(_(L"MENU_RESTORE",L"_Restore..."),restoreAction)
+        ->AddSeparator()
+        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
+    menu
+      ->AddMenuItemSub(_ld(menuEdit))
+        ->AddMenuItemAction(_(L"MENU_STATISTICS",L"_Statistics..."),statisticsAction)
+        ->AddSeparator()
+        ->AddMenuItemAction(_ld(menuEditSettings),Lum::OS::qualifierControl,L"p",configAction);
+    menu
+      ->AddMenuItemSub(_ld(menuHelp))
+        ->AddMenuItemAction(_ld(menuHelpHelp),helpAction)
+        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
 
-    menu=new Lum::Menu();
-    menu->AddActionItem(_(L"MENU_STATISTICS",L"_Statistics..."),statisticsAction);
-    menu->AddSeparator();
-    menu->AddActionItem(_ld(menuEditSettings),configAction,Lum::OS::qualifierControl,L"p");
-    menuStrip->AddPullDownMenu(_ld(menuEdit),menu);
-
-    menu=new Lum::Menu();
-    menu->AddActionItem(_ld(menuHelpHelp),helpAction);
-    menu->AddActionItem(_ld(menuHelpAbout),aboutAction);
-    menuStrip->AddPullDownMenu(_ld(menuHelp),menu);
-
-    wGroup->SetMenuStrip(menuStrip);
-
-    SetTop(wGroup);
+    SetMenu(menu);
 
     Dialog::PreInit();
   }
@@ -179,6 +160,7 @@ public:
                               L"Cannot load configuration!");
       }
 
+      foodInput->InitializeGUI();
       dataInput->InitializeGUI();
     }
     else if (model==GetClosedAction() && GetClosedAction()->IsFinished()) {
@@ -190,7 +172,7 @@ public:
     }
     else if (model==importAction && importAction->IsFinished()) {
       Import(this);
-      dataInput->UpdateFoods();
+      foodInput->UpdateFoods();
     }
     else if (model==exportAction && exportAction->IsFinished()) {
       Export(this);
@@ -250,19 +232,6 @@ public:
 
       delete dialog;
     }
-    else if (model==helpAction && helpAction->IsFinished()) {
-      Help *dialog;
-
-      dialog=new Help();
-      dialog->SetParent(this);
-
-      if (dialog->Open()) {
-        dialog->EventLoop();
-        dialog->Close();
-      }
-
-      delete dialog;
-    }
     else if (model==configAction && configAction->IsFinished()) {
       Preferences *dialog;
 
@@ -276,6 +245,9 @@ public:
 
       delete dialog;
     }
+    else if (model==helpAction && helpAction->IsFinished()) {
+      Lum::Dlg::Help::Show(this,_(L"HELP_CONTENT",L"No help available"));
+    }
     else if (model==aboutAction && aboutAction->IsFinished()) {
       Lum::Dlg::About::Show(this,info);
     }
@@ -293,6 +265,8 @@ public:
     Lum::Base::Path::SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
 #endif
 
+    Lum::Base::L10N::SetFallbackLocale(L"en");
+
     info.SetProgram(Lum::Base::StringToWString(PACKAGE_NAME));
     info.SetVersion(Lum::Base::StringToWString(PACKAGE_VERSION));
     info.SetDescription(_(L"ABOUT_DESC",L"Control your weight..."));
